@@ -4,7 +4,7 @@ from invenio_records_resources.records.api import Record
 from invenio_records_resources.records.systemfields import IndexField
 from invenio_records_resources.records.systemfields.pid import PIDField, PIDFieldContext
 from invenio_vocabularies.records.api import Vocabulary
-from oarepo_runtime.relations import InternalRelation, PIDRelation, RelationsField
+from oarepo_runtime.relations import PIDRelation, RelationsField
 
 from nr_metadata.common.records.dumper import CommonDumper
 from nr_metadata.common.records.models import CommonMetadata
@@ -19,7 +19,7 @@ class CommonRecord(Record):
     index = IndexField("common-common-1.0.0")
 
     pid = PIDField(
-        create=True, provider=RecordIdProviderV2, context_cls=PIDFieldContext
+        provider=RecordIdProviderV2, context_cls=PIDFieldContext, create=True
     )
 
     dumper_extensions = [MultilingualDumper()]
@@ -28,7 +28,7 @@ class CommonRecord(Record):
     relations = RelationsField(
         affiliations_item=PIDRelation(
             "metadata.creators.affiliations",
-            keys=["id", "title"],
+            keys=["id", "title", "hierarchy"],
             pid_field=Vocabulary.pid.with_type_ctx("institutions"),
         ),
         role=PIDRelation(
@@ -38,7 +38,7 @@ class CommonRecord(Record):
         ),
         affiliations_item_1=PIDRelation(
             "metadata.contributors.affiliations",
-            keys=["id", "title"],
+            keys=["id", "title", "hierarchy"],
             pid_field=Vocabulary.pid.with_type_ctx("institutions"),
         ),
         resourceType=PIDRelation(
@@ -59,7 +59,7 @@ class CommonRecord(Record):
         rights_item=PIDRelation(
             "metadata.rights",
             keys=["id", "title"],
-            pid_field=Vocabulary.pid.with_type_ctx("access-rights"),
+            pid_field=Vocabulary.pid.with_type_ctx("licenses"),
         ),
         accessRights=PIDRelation(
             "metadata.accessRights",
@@ -68,7 +68,7 @@ class CommonRecord(Record):
         ),
         affiliations_item_2=PIDRelation(
             "metadata.relatedItems.itemCreators.affiliations",
-            keys=["id", "title"],
+            keys=["id", "title", "hierarchy"],
             pid_field=Vocabulary.pid.with_type_ctx("institutions"),
         ),
         role_1=PIDRelation(
@@ -78,7 +78,7 @@ class CommonRecord(Record):
         ),
         affiliations_item_3=PIDRelation(
             "metadata.relatedItems.itemContributors.affiliations",
-            keys=["id", "title"],
+            keys=["id", "title", "hierarchy"],
             pid_field=Vocabulary.pid.with_type_ctx("institutions"),
         ),
         itemRelationType=PIDRelation(
