@@ -1,19 +1,8 @@
 import marshmallow as ma
-from edtf import Date as EDTFDate
-from edtf import Interval as EDTFInterval
-from invenio_records_resources.services.records.schema import (
-    BaseRecordSchema as InvenioBaseRecordSchema,
-)
-from invenio_vocabularies.services.schema import i18n_strings
-from marshmallow import ValidationError
 from marshmallow import fields as ma_fields
-from marshmallow import validate as ma_validate
-from marshmallow_utils import fields as mu_fields
-from marshmallow_utils import schemas as mu_schemas
-from marshmallow_utils.fields import edtfdatestring as mu_fields_edtf
 from oarepo_runtime.i18n.schema import I18nUISchema
 from oarepo_runtime.ui import marshmallow as l10n
-from oarepo_runtime.validation import validate_date
+from oarepo_vocabularies.services.ui_schemas import HierarchyUISchema, I18nStrUIField
 
 from nr_metadata.ui_schema.identifiers import (
     NRAuthorityIdentifierUISchema,
@@ -33,7 +22,8 @@ class NRAffiliationVocabularyUISchema(ma.Schema):
     """NRAffiliationVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
+    hierarchy = ma_fields.Nested(lambda: HierarchyUISchema())
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -54,7 +44,7 @@ class NRAuthorityRoleVocabularyUISchema(ma.Schema):
     """NRAuthorityRoleVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -76,7 +66,7 @@ class NRResourceTypeVocabularyUISchema(ma.Schema):
     """NRResourceTypeVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -93,7 +83,7 @@ class NRSubjectCategoryVocabularyUISchema(ma.Schema):
     """NRSubjectCategoryVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -101,7 +91,15 @@ class NRLanguageVocabularyUISchema(ma.Schema):
     """NRLanguageVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
+    _version = ma_fields.String(data_key="@v", attribute="@v")
+
+
+class NRLicenseVocabularyUISchema(ma.Schema):
+    """NRLicenseVocabularyUISchema schema."""
+
+    _id = ma_fields.String(data_key="id", attribute="id")
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -109,7 +107,7 @@ class NRAccessRightsVocabularyUISchema(ma.Schema):
     """NRAccessRightsVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -117,7 +115,7 @@ class NRItemRelationTypeVocabularyUISchema(ma.Schema):
     """NRItemRelationTypeVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -143,7 +141,7 @@ class NRFunderVocabularyUISchema(ma.Schema):
     """NRFunderVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -188,7 +186,7 @@ class NRCountryVocabularyUISchema(ma.Schema):
     """NRCountryVocabularyUISchema schema."""
 
     _id = ma_fields.String(data_key="id", attribute="id")
-    title = i18n_strings
+    title = I18nStrUIField()
     _version = ma_fields.String(data_key="@v", attribute="@v")
 
 
@@ -230,9 +228,7 @@ class NRCommonMetadataUISchema(ma.Schema):
     abstract = ma_fields.List(ma_fields.Nested(lambda: I18nUISchema()))
     methods = ma_fields.List(ma_fields.Nested(lambda: I18nUISchema()))
     technicalInfo = ma_fields.List(ma_fields.Nested(lambda: I18nUISchema()))
-    rights = ma_fields.List(
-        ma_fields.Nested(lambda: NRAccessRightsVocabularyUISchema())
-    )
+    rights = ma_fields.List(ma_fields.Nested(lambda: NRLicenseVocabularyUISchema()))
     accessRights = ma_fields.Nested(lambda: NRAccessRightsVocabularyUISchema())
     relatedItems = ma_fields.List(ma_fields.Nested(lambda: NRRelatedItemUISchema()))
     fundingReferences = ma_fields.List(
