@@ -1,9 +1,8 @@
-from invenio_records_resources.services import RecordLink
-from invenio_records_resources.services import RecordServiceConfig
 from invenio_records_resources.services import (
-    RecordServiceConfig as InvenioRecordServiceConfig,
+    RecordLink,
+    RecordServiceConfig,
+    pagination_links,
 )
-from invenio_records_resources.services import pagination_links
 
 from nr_metadata.documents.records.api import DocumentsRecord
 from nr_metadata.documents.services.records.permissions import DocumentsPermissionPolicy
@@ -23,7 +22,6 @@ class DocumentsServiceConfig(RecordServiceConfig):
     search = DocumentsSearchOptions
 
     record_cls = DocumentsRecord
-    # todo should i leave this here?
     service_id = "documents"
 
     components = [*RecordServiceConfig.components]
