@@ -1,7 +1,6 @@
 """Facet definitions."""
 
 from invenio_records_resources.services.records.facets import TermsFacet
-from invenio_search.engine import dsl
 from oarepo_runtime.facets.nested_facet import NestedLabeledFacet
 
 metadata_thesis_dateDefended = TermsFacet(field="metadata.thesis.dateDefended")
@@ -76,6 +75,21 @@ metadata_creators_affiliations_id = TermsFacet(
 )
 
 
+metadata_creators_affiliations_hierarchy_parent = TermsFacet(
+    field="metadata.creators.affiliations.hierarchy.parent"
+)
+
+
+metadata_creators_affiliations_hierarchy_level = TermsFacet(
+    field="metadata.creators.affiliations.hierarchy.level"
+)
+
+
+metadata_creators_affiliations_hierarchy_ancestors = TermsFacet(
+    field="metadata.creators.affiliations.hierarchy.ancestors"
+)
+
+
 metadata_creators_affiliations__version = TermsFacet(
     field="metadata.creators.affiliations.@v"
 )
@@ -108,6 +122,21 @@ metadata_contributors_affiliations_id = TermsFacet(
 )
 
 
+metadata_contributors_affiliations_hierarchy_parent = TermsFacet(
+    field="metadata.contributors.affiliations.hierarchy.parent"
+)
+
+
+metadata_contributors_affiliations_hierarchy_level = TermsFacet(
+    field="metadata.contributors.affiliations.hierarchy.level"
+)
+
+
+metadata_contributors_affiliations_hierarchy_ancestors = TermsFacet(
+    field="metadata.contributors.affiliations.hierarchy.ancestors"
+)
+
+
 metadata_contributors_affiliations__version = TermsFacet(
     field="metadata.contributors.affiliations.@v"
 )
@@ -251,6 +280,21 @@ metadata_relatedItems_itemCreators_affiliations_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemCreators_affiliations_hierarchy_parent = TermsFacet(
+    field="metadata.relatedItems.itemCreators.affiliations.hierarchy.parent"
+)
+
+
+metadata_relatedItems_itemCreators_affiliations_hierarchy_level = TermsFacet(
+    field="metadata.relatedItems.itemCreators.affiliations.hierarchy.level"
+)
+
+
+metadata_relatedItems_itemCreators_affiliations_hierarchy_ancestors = TermsFacet(
+    field="metadata.relatedItems.itemCreators.affiliations.hierarchy.ancestors"
+)
+
+
 metadata_relatedItems_itemCreators_affiliations__version = TermsFacet(
     field="metadata.relatedItems.itemCreators.affiliations.@v"
 )
@@ -291,6 +335,21 @@ metadata_relatedItems_itemContributors_affiliations_id = TermsFacet(
 )
 
 
+metadata_relatedItems_itemContributors_affiliations_hierarchy_parent = TermsFacet(
+    field="metadata.relatedItems.itemContributors.affiliations.hierarchy.parent"
+)
+
+
+metadata_relatedItems_itemContributors_affiliations_hierarchy_level = TermsFacet(
+    field="metadata.relatedItems.itemContributors.affiliations.hierarchy.level"
+)
+
+
+metadata_relatedItems_itemContributors_affiliations_hierarchy_ancestors = TermsFacet(
+    field="metadata.relatedItems.itemContributors.affiliations.hierarchy.ancestors"
+)
+
+
 metadata_relatedItems_itemContributors_affiliations__version = TermsFacet(
     field="metadata.relatedItems.itemContributors.affiliations.@v"
 )
